# 使用说明

## 基本概念
- QAlgo 的设计理念
- 与 PySparQ 的关系

## 算法列表
### 已实现
- 线性求解器 (Quantum Linear System Solver)，基于离散绝热定理

### 待实现
- Shor算法
- 线性求解器 (Quantum Linear System Solver)，基于Quantum Walk
- 线性求解器 (Quantum Linear System Solver)，基于HHL算法
- 量子态制备

